import os
import sys
import argparse

env_path = os.path.join(os.path.dirname(__file__), '..')
if env_path not in sys.path:
    sys.path.append(env_path)

from pytracking.evaluation import get_dataset
from pytracking.evaluation.running import run_dataset
from pytracking.evaluation import Tracker

os.environ['CUDA_VISIBLE_DEVICES'] = '4'

def run_tracker(tracker_name, tracker_param, run_id=None, dataset_name='cdtb', dtype='rgb', sequence=None, debug=0, threads=0,
                visdom_info=None):
    """Run tracker on sequence or dataset.
    args:
        tracker_name: Name of tracking method.
        tracker_param: Name of parameter file.
        run_id: The run id.
        dataset_name: Name of dataset (otb, nfs, uav, tpl, vot, tn, gott, gotv, lasot).
        sequence: Sequence number or name.
        debug: Debug level.
        threads: Number of threads.
        visdom_info: Dict optionally containing 'use_visdom', 'server' and 'port' for Visdom visualization.
    """

    visdom_info = {} if visdom_info is None else visdom_info
    dataset = get_dataset(dtype, dataset_name)

    if sequence is not None:
        dataset = [dataset[sequence]]

    trackers = [Tracker(tracker_name, tracker_param, run_id)]

    run_dataset(dataset, trackers, debug, threads, visdom_info=visdom_info, run_id=run_id) # Song add run_id for box_file saving


'''  One more parameter,
        --input_dtype : including rgb, rgbcolormap, colormap, raw_depth, normalized_depth, rgb_rawdepth, rgb_normdepth,
                        here, we use the rgbcolormap, which includes the rgb + colormap of depth images,


    CUDA_VISIBLE_DEVICES=0 python run_tracker.py dimp DeT_DiMP50_Max --dataset_name depthtrack --input_dtype rgbcolormap --sequence adapter01_indoor --debug 1

    CUDA_VISIBLE_DEVICES=0 python run_tracker.py dimp DeT_DiMP50_Max --dataset_name depthtrack --input_dtype rgbcolormap

    CUDA_VISIBLE_DEVICES=0 python run_tracker.py dimp DeT_DiMP50_Max --dataset_name cdtb --input_dtype rgbcolormap
    
'''
def main():
    parser = argparse.ArgumentParser(description='Run tracker on sequence or dataset.')
    # parser.add_argument('tracker_name', type=str, help='Name of tracking method.')
    # parser.add_argument('tracker_param', type=str, help='Name of parameter file.')
    # parser.add_argument('--dataset_name', type=str, default='otb', help='Name of dataset (otb, nfs, uav, tpl, vot, tn, gott, gotv, lasot).')
    # parser.add_argument('--input_dtype', type=str, default='colormap', help='[colormap, raw depth, normalized_depth, ....]')
    parser.add_argument('--sequence', type=str, default=None, help='Sequence number or name.')
    parser.add_argument('--debug', type=int, default=0, help='Debug level.')
    parser.add_argument('--runxid', type=int, default=None, help='The run id.')
    parser.add_argument('--threads', type=int, default=0, help='Number of threads.')
    parser.add_argument('--use_visdom', type=bool, default=True, help='Flag to enable visdom.')
    parser.add_argument('--visdom_server', type=str, default='127.0.0.1', help='Server for visdom.')
    parser.add_argument('--visdom_port', type=int, default=8097, help='Port for visdom.')

    args = parser.parse_args()

    try:
        seq_name = int(args.sequence)
    except:
        seq_name = args.sequence

    run_tracker('dimp', 'DeT_DiMP50_Max', None, 'cdtb','rgb3d', seq_name, args.debug,
                args.threads, {'use_visdom': args.use_visdom, 'server': args.visdom_server, 'port': args.visdom_port})


if __name__ == '__main__':
    main()
